Use-Case Analysis and Design
============================

In this section, we will address the previously stated requirements.
Each use case previously defined will be analyzed and from there we design
the logical flow for the implementation.  Due to the time limitation, we could
only designed the system for some few use cases related to authentication
and project management.

.. toctree::
   :maxdepth: 2

   security
   project
   file
